/*
 * File lexical.h
 * Interface to lexical.c
 *
 * The Unknown Scandinavian was here
 * 24-OCT-1990
 */

/*********************************************************************
 * Externally available data
 */

extern int	token_int;		/* value of digits */
extern char	token_string[];		/* names, quoted-strings */
extern int	token_dollars;		/* dollars in a name */
extern int	token_overflow;		/* name truncated */
extern int	token_collision;	/* tokens collide */

extern int	token_byte;		/* #chars scanned */
extern int	token_line;		/* #lines scanned */
extern int	token_col;		/* #columns of last line */
extern int	token_count;		/* #tokens scanned */

/*********************************************************************
 * Functions
 */

extern int newfile ();
extern int nofile ();
extern int token ();			/* w/o comments */
extern int raw_token ();		/* w/ comments */

/*********************************************************************
 * Tokens returned
 */

#define TOKEN_EOF	-1		/* End of File */
#define TOKEN_NIL	 0		/* Illegal Lexeme */
#define TOKEN_ASSIGN	 1		/* Assignment Operator */
#define TOKEN_COLON	 2
#define TOKEN_COMMA	 3
#define TOKEN_DIGITS	 4
/* Returns for Digits:
 *	token_int = value
 */
#define TOKEN_DIV	 5		/* Divide */
#define TOKEN_DOT	 6		/* Fetch Operator */
#define TOKEN_ECOMM	 7		/* Embedded Comment */
/* Returns for an Embedded Comment:
 *	token_int = length of comment
 *	token_collision = (unexpected EOF) ? 1 : 0
 */
#define TOKEN_LANG	 8		/* Left Angle Bracket */
#define TOKEN_LBRACK	 9		/* Left Bracket */
#define TOKEN_LPAREN	10		/* Left Parenthesis */
#define TOKEN_MINUS	11
#define TOKEN_MUL	12		/* Multiply */
#define TOKEN_NAME	13		/* Name or keyword */
/* Returns for a Name:
 *	token_int = the full length of the name
 *	token_string = the first 31 chars, null-terminated
 *	token_overflow = (token_int > 31) ? 1 : 0
 *	token_collision = (lookahead = '%') ? 1 : 0
 *	token_dollars = (contains '$') ? 1 : 0
 */
#define TOKEN_PERC	14		/* Percent */
#define TOKEN_PLUS	15
#define TOKEN_POW	16		/* Caret */
#define TOKEN_RANG	17		/* Right Angle Bracket */
#define TOKEN_RBRACK	18		/* Right Bracket */
#define TOKEN_RPAREN	19		/* Right Parenthesis */
#define TOKEN_SEMI	20		/* Semicolon */
#define TOKEN_STRING	21		/* Quoted String */
/* Returns for a Quoted String:
 *	token_int = the full length of the string
 *	token_string = the first 255 chars, null-terminated
 *	token_overflow = (token_int > 255) ? 1 : 0
 *	token_collision = (contains cntrl other than tab
 *			   || unexpected EOF) ? 1 : 0
 *		Such cntrls are stored as blanks.
 */
#define TOKEN_TCOMM	22		/* Trailing Comment */
/* Returns for a trailing comment:
 *	token_int = length of comment
 */


